pub enum QueryCommand {
DefaultValue,
CurrentValue,
RangeValue,
}Expand description
Represents special characters used to modify other serial commands to query command values.
Variants
DefaultValue
Gets the default value for the command.
CurrentValue
Gets the current value for the command.
RangeValue
Gets the range of acceptable values for the command.
Implementations
Sourceimpl QueryCommand
impl QueryCommand
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new QueryCommand.
Sourcepub const fn command(&self) -> &str
pub const fn command(&self) -> &str
Gets the ASCII-encoded serial command for the QueryCommand.